﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Buzz.MachineInterface;

namespace WDE.EasyRec
{

    public class SampleData
    {
        private float [] sampleData;        
        private int defaultSize = 44100 * 4 * 2; // 10 seconds 
        private int appendPos;

        public SampleData()
        {
            Init();
        }

        public void Init()
        {
            sampleData = new float[defaultSize];
            appendPos = 0;
        }

        public float [] GetBuffer()
        {
            return sampleData;
        }

        public void AddSample(Sample sample, int pos)
        {            
            if (pos*2 >= sampleData.Length)
            {
                Array.Resize(ref sampleData, pos*2 + defaultSize);
            }

            sampleData[pos * 2] = sample.L;
            sampleData[pos * 2+1] = sample.R;            
        }

        public Sample GetSample(int pos)
        {            
            Sample sample = new Sample(0.0f);
            if (pos*2+1 < sampleData.Length)
            {
                sample.L = sampleData[pos * 2];
                sample.R = sampleData[pos * 2 + 1];
            }
            return sample;
        }

        internal void GetSampleBuf(ref Sample[] output, int numsamples, int playPosition)
        {
            for (int i = 0; i < numsamples; i++)
            {
                output[i] = this.GetSample(playPosition + i);
            }
        }

        internal void AddSampleBuf(Sample[] input, int numsamples, int playPosition)
        {
            for (int i = 0; i < numsamples; i++)
            {
                this.AddSample(input[i], playPosition + i);
            }

        }

        public void ZeroBuffers()
        {
            for (int i = 0; i < sampleData.Length; i++)
            {
                sampleData[i] = 0.0f;
            }
        }

        internal void NewRecord()
        {
            Init();
        }

        internal void Append(Sample[] input, int numsamples)
        {
            for (int i = 0; i < numsamples; i++)
            {
                this.AddSample(input[i], appendPos++);
            }            
        }

        public bool IsEmpty()
        {
            return appendPos == 0;
        }

        internal void AppendSilence(int numsamples)
        {
            for (int i = 0; i < numsamples; i++)
            {
                this.AddSample(new Sample(), appendPos++);
            }    
        }
    }
}
